@@ -2,6 +2,7 @@ use swc_common::{collections::AHashMap, SyntaxContext};
 use swc_ecma_ast::*;
 use swc_ecma_utils::ident::IdentLike;
 use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith};
+use swc_trace_macro::swc_trace;
 
 pub(super) fn rename(map: AHashMap<Id, Id>) -> Rename {
     Rename { map }
@@ -11,6 +12,7 @@ pub(super) struct Rename {
     map: AHashMap<Id, Id>,
 }
 
+#[swc_trace]
 impl VisitMut for Rename {
     noop_visit_mut_type!();
 
